==> cscec5b-rmat-impl-3.0.1-20221025.085610-22-sources.jar: com/ejianc/business/rmat/bean/RestituteOtherEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 其他费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_restitute_other")
public class RestituteOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="restitute_id")
    private Long restituteId; // 退赔单主键
    @TableField(value="cose_name")
    private String coseName; // 费用名称
    @TableField(value="other_price")
    private BigDecimal otherPrice; // 单价
    @TableField(value="other_num")
    private BigDecimal otherNum; // 数量
    @TableField(value="current_amount")
    private BigDecimal currentAmount; // 本期金额
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public String getCoseName() {
        return coseName;
    }

    public void setCoseName(String coseName) {
        this.coseName = coseName;
    }
    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }
    public BigDecimal getOtherNum() {
        return otherNum;
    }

    public void setOtherNum(BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    public BigDecimal getCurrentAmount() {
        return currentAmount;
    }

    public void setCurrentAmount(BigDecimal currentAmount) {
        this.currentAmount = currentAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> cscec5b-rmat-impl-3.0.1-20221122.102656-95-sources.jar: com/ejianc/business/rmat/bean/RestituteOtherEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 其他费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_restitute_other")
public class RestituteOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="restitute_id")
    private Long restituteId; // 退赔单主键
    @TableField(value="cose_name")
    private String coseName; // 费用名称
    @TableField(value="other_price")
    private BigDecimal otherPrice; // 单价
    @TableField(value="other_num")
    private BigDecimal otherNum; // 数量
    @TableField(value="current_amount")
    private BigDecimal currentAmount; // 本期金额(无税)
    @TableField(value="current_tax_amount")
    private BigDecimal currentTaxAmount; // 本期金额(含税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    
    
    

    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public String getCoseName() {
        return coseName;
    }

    public void setCoseName(String coseName) {
        this.coseName = coseName;
    }
    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }
    public BigDecimal getOtherNum() {
        return otherNum;
    }

    public void setOtherNum(BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    public BigDecimal getCurrentAmount() {
        return currentAmount;
    }

    public void setCurrentAmount(BigDecimal currentAmount) {
        this.currentAmount = currentAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getCurrentTaxAmount() {
        return currentTaxAmount;
    }

    public void setCurrentTaxAmount(BigDecimal currentTaxAmount) {
        this.currentTaxAmount = currentTaxAmount;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
}
